@@ -25,14 +25,16 @@
  * precedence is structured in regular expressions.  Serious changes in
  * regular-expression syntax might require a total rethink.
  *
- * January, 1994, M.E.: consolidated files, changed names of external
+ * January, 1994, M.E.: Consolidated files, changed names of external
  * 			functions to avoid potential conflicts with native
  *			regcomp and regexec functions, changed error
  *			reporting to NEdit form, added multi-line and
  *			reverse searching, and added \n \t \u \U \l \L.
+ * June, 1996, M.E.:	Bug in NEXT macro, didn't work for expressions
+ *  	    	    	which compiled to over 256 bytes.
  */
-static char SCCSID[] = "@(#)regularExp.c	1.4     9/23/94";
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include "regularExp.h"
@@ -92,9 +94,11 @@ static char SCCSID[] = "@(#)regularExp.c	1.4     9/23/94";
 #define NOTHING 9   /* no   Match empty string. */
 #define STAR	10  /* node Match this (simple) thing 0 or more times. */
 #define PLUS	11  /* node Match this (simple) thing 1 or more times. */
+#define BOWORD	12  /* no   	Match "" representing word delimiter or BOL */
+#define EOWORD	13  /* no   	Match "" representing word delimiter or EOL */
 #define OPEN	20  /* no   Mark this point in input as start of #n. */
 	    	    /*	OPEN+1 is number 1, etc. */
-#define CLOSE	30  /* no   Analogous to OPEN. */
+#define CLOSE	(OPEN + NSUBEXP)  /* no   Analogous to OPEN. */
 
 /*
  * Opcode notes:
@@ -129,7 +133,7 @@ static char SCCSID[] = "@(#)regularExp.c	1.4     9/23/94";
  * but allows patterns to get big without disasters.
  */
 #define OP(p)	(*(p))
-#define NEXT(p) (((*((p)+1)&0377)<<8) + *((p)+2)&0377)
+#define NEXT(p) (((*((p)+1)&0377)<<8) + ((*((p)+2))&0377))
 #define OPERAND(p)  ((p) + 3)
 
 /*
@@ -138,7 +142,7 @@ static char SCCSID[] = "@(#)regularExp.c	1.4     9/23/94";
 #define UCHARAT(p)  ((int)*(unsigned char *)(p))
 #define FAIL(m) { *errorpointer = m; return(NULL); }
 #define ISMULT(c)   ((c) == '*' || (c) == '+' || (c) == '?')
-#define META	"^$.[()|?+*\\"
+#define META	"^$.[()|?+*\\<>"
 
 /*
  * Flags to be passed up and down.
@@ -162,18 +166,18 @@ static char **errorpointer; /* Place to store error messages so they can be
 /*
  * Forward declarations for CompileRE()'s friends.
  */
-static char *reg();
-static char *regbranch();
-static char *regpiece();
-static char *regatom();
-static char *regnode();
-static char *regnext();
-static void regc();
-static void reginsert();
-static void regtail();
-static void regoptail();
-static void regerror();
-static char regescape();
+static char *reg(int paren, int *flagp);
+static char *regbranch(int *flagp);
+static char *regpiece(int *flagp);
+static char *regatom(int *flagp);
+static char *regnode(char op);
+static char *regnext(char *p);
+static void regc(char b);
+static void reginsert(char op, char *opnd);
+static void regtail(char *p, char *val);
+static void regoptail(char *p, char *val);
+static void regerror(char *s);
+static char regescape(char c);
 
 /*
  - CompileRE - compile a regular expression into internal code
@@ -190,17 +194,13 @@ static char regescape();
  * Beware that the optimization-preparation code in here knows about some
  * of the structure of the compiled regexp.
  */
-regexp *
-CompileRE(exp, errorText)
-char *exp;
-char **errorText;
+regexp *CompileRE(char *exp, char **errorText)
 {
     register regexp *r;
     register char *scan;
     register char *longest;
     register int len;
     int flags;
-    extern char *malloc();
 
     /* Set up errorText to receive failure reports */
     errorpointer = errorText;
@@ -283,10 +283,7 @@ char **errorText;
  * is a trifle forced, but the need to tie the tails of the branches to what
  * follows makes it hard to avoid.
  */
-static char *
-reg(paren, flagp)
-int paren;	    /* Parenthesized? */
-int *flagp;
+static char *reg(int paren, int *flagp)
 {
     register char *ret;
     register char *br;
@@ -355,9 +352,7 @@ int *flagp;
  *
  * Implements the concatenation operator.
  */
-static char *
-regbranch(flagp)
-int *flagp;
+static char *regbranch(int *flagp)
 {
     register char *ret;
     register char *chain;
@@ -394,9 +389,7 @@ int *flagp;
  * It might seem that this node could be dispensed with entirely, but the
  * endmarker role is not redundant.
  */
-static char *
-regpiece(flagp)
-int *flagp;
+static char *regpiece(int *flagp)
 {
     register char *ret;
     register char op;
@@ -458,9 +451,7 @@ int *flagp;
  * faster to run.  Backslashed characters are exceptions, each becoming a
  * separate node; the code is simpler that way and it's not worth fixing.
  */
-static char *
-regatom(flagp)
-int *flagp;
+static char *regatom(int *flagp)
 {
     register char *ret;
     int flags;
@@ -474,6 +465,12 @@ int *flagp;
     case '$':
 	ret = regnode(EOL);
 	break;
+    case '<':
+	ret = regnode(BOWORD);
+	break;
+    case '>':
+	ret = regnode(EOWORD);
+	break;
     case '.':
 	ret = regnode(ANY);
 	*flagp |= HASWIDTH|SIMPLE;
@@ -576,9 +573,7 @@ int *flagp;
 /*
  - regnode - emit a node
  */
-static char *		/* Location. */
-regnode(op)
-char op;
+static char *regnode(char op)
 {
     register char *ret;
     register char *ptr;
@@ -601,9 +596,7 @@ char op;
 /*
  - regc - emit (if appropriate) a byte of code
  */
-static void
-regc(b)
-char b;
+static void regc(char b)
 {
     if (regcode != &regdummy)
 	*regcode++ = b;
@@ -616,10 +609,7 @@ char b;
  *
  * Means relocating the operand.
  */
-static void
-reginsert(op, opnd)
-char op;
-char *opnd;
+static void reginsert(char op, char *opnd)
 {
     register char *src;
     register char *dst;
@@ -645,10 +635,7 @@ char *opnd;
 /*
  - regtail - set the next-pointer at the end of a node chain
  */
-static void
-regtail(p, val)
-char *p;
-char *val;
+static void regtail(char *p, char *val)
 {
     register char *scan;
     register char *temp;
@@ -678,14 +665,12 @@ char *val;
  - regescape - recognize legal escape (prefixed with backslash) characters,
  - and translate them into the corresponding ascii code
  */
-static char
-regescape(c)
-char c;
+static char regescape(char c)
 {
     static char escape[] =  {'*','+','?','(',')','^','|','.','$','&','\\',
-    	'[', ']', 'n','t','b','r','f','\0'};
+    	'[', ']', '<', '>', '\"', '\'', 'n','t','b','r','f', 'a', 'v', '\0'};
     static char replace[] = {'*','+','?','(',')','^','|','.','$','&','\\',
-    	'[', ']', '\n','\t','\b','\r','\f','\0'};
+    	'[', ']', '<', '>', '\"', '\'','\n','\t','\b','\r','\f','\a','\v','\0'};
     int i;
     
     for (i=0; escape[i] != '\0'; i++)
@@ -698,10 +683,7 @@ char c;
 /*
  - regoptail - regtail on operand of first argument; nop if operandless
  */
-static void
-regoptail(p, val)
-char *p;
-char *val;
+static void regoptail(char *p, char *val)
 {
     /* "Operandless" and "op != BRANCH" are synonymous in practice. */
     if (p == NULL || p == &regdummy || OP(p) != BRANCH)
@@ -716,18 +698,23 @@ char *val;
 /*
  * Global work variables for ExecRE().
  */
-static char *reginput;	    /* String-input pointer. */
-static char *startofstring; /* Beginning of input, for ^ check. */
-static char **regstartp;    /* Pointer to startp array. */
-static char **regendp;	    /* Ditto for endp. */
-
+static char *reginput;	      /* String-input pointer. */
+static char *startofstring;   /* Beginning of input, for ^ and < checks. */
+static int stringstartsline;  /* input begins is line boundary */
+static int stringstartsword;  /* input begins at word boundary */
+static char **regstartp;      /* Pointer to startp array. */
+static char **regendp;	      /* Ditto for endp. */
+static char defaultdelimiters[256] = {0}; /* Default table for determining
+				 whether a character is a word delimiter */
+static char *isdelimiter;     /* Current delimiter table */
 /*
  * Forwards.
  */
-static int regtry();
-static int regmatch();
-static int regrepeat();
-static void adjustcase();
+static int regtry(regexp *prog, char *string);
+static int regmatch(char *prog);
+static int regrepeat(char *p);
+static void adjustcase(char *str, int len, char chgcase);
+static char *makeDelimiterTable(char *delimiters, char *table);
 
 /*
  - ExecRE - match a regexp against a string
@@ -736,17 +723,19 @@ static void adjustcase();
  * it.  If reverse is true, end must be specified, and searching begins at end.
  * isbol should be set to true if the beginning of the string is the actual
  * beginning of a line (since ExecRE can't look backwards from the beginning
- * to find whether there was a newline before).
+ * to find whether there was a newline before).  Likewise, isbow asks whether
+ * the string is preceded by a word delimiter.  End of string is always treated
+ * as a word and line boundary (there may be cases where it shouldn't be, in
+ * which case, this should be changed).  "delimit" (if non-null) specifies
+ * a null-terminated string of characters to be considered word delimiters
+ * matching "<" and ">".  if "delimit" is NULL, the default delimiters (as set
+ * in SetREDefaultWordDelimiters are used.
  */
-int
-ExecRE(prog, string, end, reverse, isbol)
-register regexp *prog;
-register char *string;
-char *end;
-int reverse;
-int isbol;
+int ExecRE(regexp *prog, char *string, char *end, int reverse, int isbol,
+	int isbow, char *delimiters)
 {
     register char *s;
+    char tempDelimitTable[256];
 
     /* Be paranoid... */
     if (prog == NULL || string == NULL) {
@@ -760,9 +749,15 @@ int isbol;
 	return(0);
     }
 
+    /* If caller has supplied delimiters, make a delimiter table */
+    if (delimiters == NULL)
+    	isdelimiter = defaultdelimiters;
+    else
+    	isdelimiter = makeDelimiterTable(delimiters, tempDelimitTable);
+
     /* If there is a "must appear" string, look for it, reject if not found. */
     if (prog->regmust != NULL) {
-	for (s=string; *s!='\0' && s==end; s++) {
+	for (s=string; *s!='\0' && s==end; s++) { /*... This must be wrong!!! */
 	    if (*s == prog->regmust[0]) {
 		if (strncmp(s, prog->regmust, prog->regmlen) == 0)
 		    break;	/* Found it. */
@@ -773,7 +768,9 @@ int isbol;
     }
 
     /* remember the beginning of the string for matching BOL */
-    startofstring = isbol ? string : NULL;
+    startofstring = string;
+    stringstartsline = isbol;
+    stringstartsword = isbow;
     
     /* Search forward */
     if (!reverse) {
@@ -808,45 +805,40 @@ int isbol;
     }
     
     /* Search reverse, same as forward, but loops run backward */
-    if (reverse) {
 	
-	/* If search is anchored at BOL */
-	if (prog->reganch) {
-	    for (s=end-1; s>string; s--)
-	    	if (*s == '\n')
-	    	    if (regtry(prog, s+1))
-	    	    	return(1);
-	    if (regtry(prog, string))
-	    	return(1);
-	    return(0);
-	}
-	
-	/* We know what char match must start with. */
-	if (prog->regstart != '\0') {
-	    for (s=end; s>string; s--)
-	    	if (*s == prog->regstart)
-	    	    if (regtry(prog, s))
-	    	    	return(1);
-	    return(0);
-	}
-	
-	/* General case */
-	for (s=end; s>string; s--)
-	    if (regtry(prog, s))
-		return(1);
-
-	/* Failure. */
+    /* If search is anchored at BOL */
+    if (prog->reganch) {
+	for (s=end-1; s>=string; s--)
+	    if (*s == '\n')
+	    	if (regtry(prog, s+1))
+	    	    return(1);
+	if (regtry(prog, string))
+	    return(1);
 	return(0);
     }
+
+    /* We know what char match must start with. */
+    if (prog->regstart != '\0') {
+	for (s=end; s>=string; s--)
+	    if (*s == prog->regstart)
+	    	if (regtry(prog, s))
+	    	    return(1);
+	return(0);
+    }
+
+    /* General case */
+    for (s=end; s>=string; s--)
+	if (regtry(prog, s))
+	    return(1);
+
+    /* Failure. */
+    return(0);
 }
 
 /*
- - regtry - try match at specific point
+ - regtry - try match at specific point, returns: 0 failure, 1 success
  */
-static int	    /* 0 failure, 1 success */
-regtry(prog, string)
-regexp *prog;
-char *string;
+static int regtry(regexp *prog, char *string)
 {
     register int i;
     register char **sp;
@@ -878,11 +870,9 @@ char *string;
  * and then act accordingly.  In practice we make some effort to avoid
  * recursion, in particular by going through "ordinary" nodes (that don't
  * need to know whether the rest of the match failed) by a loop instead of
- * by recursion.
+ * by recursion.  Returns 0 failure, 1 success
  */
-static int	    /* 0 failure, 1 success */
-regmatch(prog)
-char *prog;
+static int regmatch(char *prog)
 {
     register char *scan;    /* Current node. */
     char *next;	    /* Next node. */
@@ -893,13 +883,30 @@ char *prog;
 
 	switch (OP(scan)) {
 	case BOL:
-	    if (reginput != startofstring && *(reginput-1) != '\n')
-		return(0);
-	    break;
+	    if (reginput == startofstring) {
+	    	if (stringstartsline)
+	    	    break;
+	    } else if (*(reginput-1) == '\n')
+	    	break;
+	    return(0);
 	case EOL:
 	    if (*reginput != '\n' && *reginput != '\0')
 		return(0);
 	    break;
+	case BOWORD:
+	    if (reginput == startofstring) {
+	    	if (stringstartsword)
+	    	    break;
+	    	else
+	    	    return(0);
+	    }
+	    if (!isdelimiter[(unsigned char)*(reginput-1)])
+	    	return(0);
+	    break;
+	case EOWORD:
+	    if (!isdelimiter[(unsigned char)*reginput])
+	    	return(0);
+	    break;
 	case ANY:
 	    if (*reginput == '\0' || *reginput == '\n')
 		return(0);
@@ -935,62 +942,6 @@ char *prog;
 	    break;
 	case BACK:
 	    break;
-	case OPEN+1:
-	case OPEN+2:
-	case OPEN+3:
-	case OPEN+4:
-	case OPEN+5:
-	case OPEN+6:
-	case OPEN+7:
-	case OPEN+8:
-	case OPEN+9: {
-		register int no;
-		register char *save;
-
-		no = OP(scan) - OPEN;
-		save = reginput;
-
-		if (regmatch(next)) {
-		    /*
-		     * Don't set startp if some later
-		     * invocation of the same parentheses
-		     * already has.
-		     */
-		    if (regstartp[no] == NULL)
-			regstartp[no] = save;
-		    return(1);
-		} else
-		    return(0);
-	    }
-	    break;
-	case CLOSE+1:
-	case CLOSE+2:
-	case CLOSE+3:
-	case CLOSE+4:
-	case CLOSE+5:
-	case CLOSE+6:
-	case CLOSE+7:
-	case CLOSE+8:
-	case CLOSE+9: {
-		register int no;
-		register char *save;
-
-		no = OP(scan) - CLOSE;
-		save = reginput;
-
-		if (regmatch(next)) {
-		    /*
-		     * Don't set endp if some later
-		     * invocation of the same parentheses
-		     * already has.
-		     */
-		    if (regendp[no] == NULL)
-			regendp[no] = save;
-		    return(1);
-		} else
-		    return(0);
-	    }
-	    break;
 	case BRANCH: {
 		register char *save;
 
@@ -1042,8 +993,46 @@ char *prog;
 	    return(1);	/* Success! */
 	    break;
 	default:
-	    regerror("memory corruption");
-	    return(0);
+	    if ((OP(scan) > OPEN) && (OP(scan) < OPEN + NSUBEXP)) {
+		register int no;
+		register char *save;
+
+		no = OP(scan) - OPEN;
+		save = reginput;
+
+		if (regmatch(next)) {
+		    /*
+		     * Don't set startp if some later
+		     * invocation of the same parentheses
+		     * already has.
+		     */
+		    if (regstartp[no] == NULL)
+			regstartp[no] = save;
+		    return(1);
+		} else
+		    return(0);
+	    } else if ((OP(scan) > CLOSE) && (OP(scan) < CLOSE + NSUBEXP)) {
+		register int no;
+		register char *save;
+
+		no = OP(scan) - CLOSE;
+		save = reginput;
+
+		if (regmatch(next)) {
+		    /*
+		     * Don't set endp if some later
+		     * invocation of the same parentheses
+		     * already has.
+		     */
+		    if (regendp[no] == NULL)
+			regendp[no] = save;
+		    return(1);
+		} else
+		    return(0);
+	    } else {
+		regerror("memory corruption");
+		return(0);
+    	    }
 	    break;
 	}
 
@@ -1061,9 +1050,7 @@ char *prog;
 /*
  - regrepeat - repeatedly match something simple, report how many
  */
-static int
-regrepeat(p)
-char *p;
+static int regrepeat(char *p)
 {
     register int count = 0;
     register char *scan;
@@ -1109,9 +1096,7 @@ char *p;
 /*
  - regnext - dig the "next" pointer out of a node
  */
-static char *
-regnext(p)
-register char *p;
+static char *regnext(char *p)
 {
     register int offset;
 
@@ -1131,12 +1116,7 @@ register char *p;
 /*
  - SubstituteRE - perform substitutions after a regexp match
  */
-void
-SubstituteRE(prog, source, dest, max)
-regexp *prog;
-char *source;
-char *dest;
-int max;
+void SubstituteRE(regexp *prog, char *source, char *dest, int max)
 {
     register char *src;
     register char *dst;
@@ -1199,30 +1179,48 @@ int max;
     *dst++ = '\0';
 }
 
-static void
-adjustcase(str, len, chgcase)
-char *str;
-int len;
-char chgcase;
+static void adjustcase(char *str, int len, char chgcase)
 {
     int i;
     
     if (chgcase == 'u')
-    	str[0] = toupper(str[0]);
+    	str[0] = toupper((unsigned char)str[0]);
     else if (chgcase == 'U')
     	for (i=0; i<len; i++)
-    	    str[i] = toupper(str[i]);
+    	    str[i] = toupper((unsigned char)str[i]);
     else if (chgcase == 'l')
-    	str[0] = tolower(str[0]);
+    	str[0] = tolower((unsigned char)str[0]);
     else if (chgcase == 'L')
     	for (i=0; i<len; i++)
-    	    str[i] = tolower(str[i]);
+    	    str[i] = tolower((unsigned char)str[i]);
 }
 
-static void
-regerror(s)
-char *s;
+static void regerror(char *s)
 {
     fprintf(stderr,
 	    "NEdit: Internal error processing regular expression (%s)\n", s);
 }
+
+void SetREDefaultWordDelimiters(char *delimiters)
+{
+    makeDelimiterTable(delimiters, defaultdelimiters);
+}
+
+/*
+** Translate a null-terminated string of delimiters into a 256 byte lookup
+** table for determining whether a character is a delimiter or not.  Table
+** must be allocated by the caller.  Return value is a pointer to the table.
+*/
+static char *makeDelimiterTable(char *delimiters, char *table)
+{
+    unsigned char *c;
+    
+    memset(table, 0, 256);
+    for (c=(unsigned char*)delimiters; *c!='\0'; c++)
+    	table[*c] = 1;
+    table[0] = 1;
+    table[' '] = 1;
+    table['\t'] = 1;
+    table['\n'] = 1;
+    return table;
+}
